Bartosz Dziewoński has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/260600

Change subject: Title: Fix typo in variable name
......................................................................

Title: Fix typo in variable name

Change-Id: I8da1c995f2da2e7a43c70aeadd28b93e5f3e511f
---
M includes/Title.php
1 file changed, 3 insertions(+), 3 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/00/260600/1

diff --git a/includes/Title.php b/includes/Title.php
index 5d8b072..35d9c6b 100644
--- a/includes/Title.php
+++ b/includes/Title.php
@@ -768,16 +768,16 @@
         * @param string $title The DB key form the title
         * @param string $fragment The link fragment (after the "#")
         * @param string $interwiki The interwiki prefix
         * @param bool $canoncialNamespace If true, use the canonical name for
         *   $ns instead of the localized version.
         * @return string The prefixed form of the title
         */
        public static function makeName( $ns, $title, $fragment = '', 
$interwiki = '',
-               $canoncialNamespace = false
+               $canonicalNamespace = false
        ) {
                global $wgContLang;
 
-               if ( $canoncialNamespace ) {
+               if ( $canonicalNamespace ) {
                        $namespace = MWNamespace::getCanonicalName( $ns );
                } else {
                        $namespace = $wgContLang->getNsText( $ns );
@@ -768,16 +768,16 @@
         * @param string $fragment The link fragment (after the "#")
         * @param string $interwiki The interwiki prefix
-        * @param bool $canoncialNamespace If true, use the canonical name for
+        * @param bool $canonicalNamespace If true, use the canonical name for
         *   $ns instead of the localized version.
         * @return string The prefixed form of the title

-- 
To view, visit https://gerrit.wikimedia.org/r/260600
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I8da1c995f2da2e7a43c70aeadd28b93e5f3e511f
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Bartosz Dziewoński <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to